.. _api:

API Reference
=============


.. attention::

    This package is still under initial development stage, so public APIs are
    not expected to be stable. Please stay updated and don't hesitate to raise
    feedback or issues through `GitHub issues <https://github.com/inlab-geo/cofi/issues/new/choose>`_
    or `Slack`_ workspace.

.. automodule:: espresso
